<?php
/**
 * GMapFactory application
 *
 * @project     MapLab
 * @revision    $Id: build_phtml.php,v 1.29.2.2.2.1 2005/09/28 19:59:31 zak Exp $
 * @purpose     This page builds the preview page.
 * @author      William A. Bronsema, C.E.T. (bronsema@dmsolutions.ca)
 * @copyright
 * <b>Copyright (c) 2002, DM Solutions Group Inc.</b>
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

/*****************************************************************************
 * $Log: build_phtml.php,v $
 * Revision 1.29.2.2.2.1  2005/09/28 19:59:31  zak
 * applied Franck Villoin's patch for browser root problem
 *
 * Revision 1.29.2.2  2004/07/21 13:17:00  zak
 * fixed map file path discovery problems when absolute path is outside file browser root path
 *
 * Revision 1.29  2003/02/11 14:40:30  sacha
 * Fixed a bug when opening a gmapfactory project from version older than rc3
 *
 * Revision 1.28  2002/10/10 19:22:23  sacha
 * File browser changed a bit so I had to change all maplab suite to use the new file browser.
 *
 * Revision 1.27  2002/08/14 00:08:19  bronsema
 * Fixed error with no reference image
 *
 * Revision 1.26  2002/08/08 03:06:50  bronsema
 * Updated to generic drawmap.php
 *
 * Revision 1.25  2002/08/02 15:05:55  bronsema
 * Updated ROSA mode to render map through drawmap.php
 *
 * Revision 1.24  2002/07/31 02:52:15  bronsema
 * Added default IMAGEURL & IMAGEPATH from XML if missing in map.
 *
 * Revision 1.23  2002/07/23 17:49:19  bronsema
 * changed html tools to contain cells
 *
 * Revision 1.22  2002/07/22 19:09:56  bronsema
 * Updated globpref code to fix logging and to turn it off.
 *
 * Revision 1.21  2002/06/28 03:15:37  bronsema
 * Updated to new session variable handler
 *
 * Revision 1.20  2002/06/13 14:13:52  sacha
 * Change copywrite msg
 *
 * Revision 1.19  2002/06/12 19:17:56  pspencer
 * made zoom buttons clickable
 *
 * Revision 1.18  2002/06/05 15:32:49  bronsema
 * Fixed Paul's last fix for extension changed icon_zoomout,gif to
 * icon_zoomout.gif :)
 *
 * Revision 1.17  2002/05/30 13:09:35  pspencer
 * missing file extensions
 *
 * Revision 1.16  2002/05/28 19:55:12  bronsema
 * Changed scalebar to use map defaults.
 *
 * Revision 1.15  2002/05/28 18:33:21  bronsema
 * Added queries
 *
 * Revision 1.14  2002/05/10 17:32:39  pspencer
 * loadModules to use config value
 *
 * Revision 1.13  2002/05/10 17:25:10  bronsema
 * Made the mapscript module a parameter in the xml config.
 *
 * Revision 1.12  2002/05/09 11:44:43  bronsema
 * Fixed bug 992 - The legend check boxes were being processed when
 * legend was off resulting in all layers being turned off.
 *
 * Revision 1.11  2002/05/02 17:27:04  bronsema
 * Changed structure
 *
 * Revision 1.10  2002/05/02 15:29:53  bronsema
 * no message
 *
 * Revision 1.9  2002/04/30 18:56:00  bronsema
 * Under construction
 *
 * Revision 1.8  2002/04/30 14:15:34  bronsema
 * Under Construction
 *
 *****************************************************************************/

// set the scope of the log file
$oLog->setScope( "build_phtml" );

// log start of process
$oLog->logFuncStart( LOG_QUIET, "Begin building of application." );

/* ============================================================================
 * Rebuild the application's globpref's page.
 * ========================================================================= */
if ( !drawGlobprefs( $http_form_vars["gszAppDir"]."globprefs.php", 
        $http_form_vars["gszAppDir"], $http_form_vars["gszWorkingDir"].
        "settings.php", $http_form_vars["gszMapFile"], $gszMapscriptModule, 
        $oLog ) )
    die( "An error occurred creating the 'globprefs.php' page." );

// log successful creation
$oLog->log( LOG_QUIET, "The 'globprefs.php' file was successfuly ".
                                                            "created." );

/* ============================================================================
 * Draw the preview page if necessary.
 * ========================================================================= */
// check if the preview page exists
if ( !file_exists($http_form_vars["gszAppDir"].$http_form_vars["gszAppName"].
                                                                    ".phtml") )
{
    // create the file
    if ( !drawPreviewPage( $http_form_vars["gszAppName"], 
                                    $http_form_vars["gszAppDir"] ,$szTitle ) )
        die( "An error occurred creating the phtml page[".
                                    $http_form_vars["gszAppName"].".phtml]." );

    // log successful creation
    $oLog->log( LOG_QUIET, "The file [".$http_form_vars["gszAppDir"]
            .$http_form_vars["gszAppName"].".phtml] was successfuly created." );
}

/* ============================================================================
 * Build the contents page
 * ========================================================================= */
// build the contents page name
$szContentsPage = $http_form_vars["gszAppDir"].$http_form_vars["gszAppName"].
                                                                "_contents.php";

// create the file from scratch
$fContents = fopen( $szContentsPage, 'w');

// create the buffer
$szBuffer = drawOpenHTML();

/* ============================================================================
 * Process and draw the contents of the first column.
 * ========================================================================= */
$aszLeftCol = buildDrawOrderArray(0, $http_form_vars["gszWorkingDir"].
                                                        "settings.php", $oLog );

// only process if there are items in the array
if (is_array($aszLeftCol))
{
    // loop through each element and draw the corresponding object
    for ($i=0; $i<6; $i++)
    {
        // only draw the object if is valid
        if ( isset($aszLeftCol[$i]) &&
            (strlen(trim($aszLeftCol[$i])) != 0) )
        {
            // draw the object
            $szBuffer = $szBuffer.drawObject( $aszLeftCol[$i], $oLog,
                                $http_form_vars["gszWorkingDir"].
                                "settings.php" );

            // if not the last item in the array then add divider
            if ($i < count($aszLeftCol)-1)
            {
                // draw the divider
                $szBuffer = $szBuffer.drawDivider();
            }
        }
    }
}

/* ============================================================================
 * Draw the HTML between column 1 and 2.
 * ========================================================================= */
$szBuffer = $szBuffer.drawHTMLInsert1();

/* ============================================================================
 * Process and draw the contents of the second column .
 * ========================================================================= */
$aszCenterCol = buildDrawOrderArray(1,$http_form_vars["gszWorkingDir"].
                                                        "settings.php", $oLog );

// only process if there are items in the array
if (is_array($aszCenterCol))
{
    // loop through each element and draw the corresponding object
    for ($i=0; $i<6; $i++)
    {
        // only draw the object if is valid
        if (isset($aszCenterCol[$i]) &&
            (strlen(trim($aszCenterCol[$i])) != 0))
        {
            // draw the object
            $szBuffer = $szBuffer.drawObject( $aszCenterCol[$i], $oLog,
                             $http_form_vars["gszWorkingDir"]."settings.php" );

            // if not the last item in the array then add divider
            if ($i < count($aszCenterCol)-1)
            {
                // draw the divider
                $szBuffer = $szBuffer.drawDivider();
            }
        }
    }
}

/* ============================================================================
 * Draw the HTML between column 2 and 3.
 * ========================================================================= */
$szBuffer = $szBuffer.drawHTMLInsert2();

/* ============================================================================
 * Process and draw the contents of the third column.
 * ========================================================================= */
$aszRightCol = buildDrawOrderArray(2, $http_form_vars["gszWorkingDir"].
                                                        "settings.php", $oLog );

// only process if there are items in the array
if (is_array($aszRightCol))
{
    // loop through each element and draw the corresponding object
    for ($i=0; $i<6; $i++)
    {
        // only draw the object if is valid
        if (isset($aszRightCol[$i]) &&
           (strlen(trim($aszRightCol[$i])) != 0) )
        {
            // draw the object
            $szBuffer = $szBuffer.drawObject( $aszRightCol[$i], $oLog,
                            $http_form_vars["gszWorkingDir"]."settings.php" );

            // if not the last item in the array then add divider
            if ($i < count($aszRightCol)-1)
            {
                // draw the divider
                $szBuffer = $szBuffer.drawDivider();
            }
        }
    }
}

/* ============================================================================
 * Draw the closing HTML
 * ========================================================================= */
// determine the rosa mode
if ( $szRadioNavType == "ROSA" )
    $nRosaMode = 1;
else
    $nRosaMode = 0;

// draw the closing HTML
$szBuffer = $szBuffer.DrawCloseHTML( $nRosaMode, $bLegend );

/* ============================================================================
 * Write and close the file
 * ========================================================================= */
fwrite($fContents, $szBuffer);

// close the file
fclose($fContents);

// log end of process
$oLog->logFuncEnd( LOG_QUIET, "End building of application." );

/**
 * This function writes the string necessary to draw the opening HTML
 *
 * @return string - Code necessary to draw the opening HTML.
 **/
function drawOpenHTML()
{
    // build the string
    $szOHBuffer = "<!---------------------->\n"
                ."<!-- BEGIN MAIN TABLE -->\n"
                ."<!---------------------->\n"
                ."<table border=\"0\" cellspacing=\"1\" cellpadding=\"2\">\n"
                ."<tr valign=\"top\">\n"
                ."<td>\n"
                ."<!------------------------------------->\n"
                ."<!-- BEGIN FIRST OF THREE SUB-TABLES -->\n"
                ."<!------------------------------------->\n"
                ."<table border=\"0\" cellspacing=\"0\" cellpadding=\"1\">\n";

    // return the string
    return $szOHBuffer;
}

/**
 * This function returns the HTML necessary to bridge column 1 and 2.
 *
 * @return string - HTML.
 **/
function drawHTMLInsert1()
{
    // build the string
    $szH1Buffer = "</table>\n"
                    ."<!----------------------------------->\n"
                    ."<!-- END FIRST OF THREE SUB-TABLES -->\n"
                    ."<!----------------------------------->\n"
                    ."</td>\n"
                    ."<td align=\"center\">\n"
                    ."<!-------------------------------------->\n"
                    ."<!-- BEGIN SECOND OF THREE SUB-TABLES -->\n"
                    ."<!-------------------------------------->\n"
                    ."<table border=\"0\" cellspacing=\"0\" cellpadding=\"1\""
                    .">\n";

    // return the string
    return $szH1Buffer;

// end drawHTMLInsert1 function
}

/**
 * This function returns the HTML necessary to bridge column 2 and 3.
 *
 * @return string - HTML.
 **/
function drawHTMLInsert2()
{
    // build the string
    $szH2Buffer = "</table>\n"
                    ."<!------------------------------------>\n"
                    ."<!-- END SECOND OF THREE SUB-TABLES -->\n"
                    ."<!------------------------------------>\n"
                    ."</td>\n"
                    ."<td>\n"
                    ."<!------------------------------------->\n"
                    ."<!-- BEGIN THIRD OF THREE SUB-TABLES -->\n"
                    ."<!------------------------------------->\n"
                    ."<table border=\"0\" cellspacing=\"0\" cellpadding=\"1\""
                            .">\n";

    // return the string
    return $szH2Buffer;

// end drawHTMLInsert2 function
}

/**
 * This function returns the HTML necessary to close the remaining HTML table
 * code.
 *
 * @return string - HTML.
 **/
/**
 * This function returns the HTML necessary to close the remaining HTML table
 * code.
 *
 * @param $nRosaMode integer - Flag indicating use of ROSA.
 * @param $bLegend boolean - Flag to indicate if legend is included or not.
 * @return string - HTML.
 **/
function drawCloseHTML( $nRosaMode, $bLegend )
{
    // build the string
    $szCHBuffer = "</table>\n"
    ."<!----------------------------------->\n"
    ."<!-- END THIRD OF THREE SUB-TABLES -->\n"
    ."<!----------------------------------->\n"
    ."</td>\n"
    ."</tr>\n"
    ."<!------------------->\n"
    ."<!-- BEGIN CREDITS -->\n"
    ."<!------------------->\n"
    ."<tr><td colspan=3>&nbsp;</td></tr>\n"
    ."<tr><td colspan=3>&nbsp;</td></tr>\n"
    ."<tr><td colspan=3>&nbsp;</td></tr>\n"
    ."<tr>\n"
    ."<td colspan=3>\n"
    ."<table width=\"100%\" cellspacing=0 cellpadding=0>\n"
    ."<tr>\n"
    ."<td bgcolor=\"#999999\"><img src=\"./images/a_pixel.gif\" width=\"1\" height=\"1\"></td>\n"
    ."</tr>\n"
    ."</table>"
    ."</td>\n"
    ."</tr>\n"
    ."<tr>\n"
    ."<td colspan=3 align=right>\n"
    ."<font face=\"Arial, Helvetica, sans-serif\" size=\"1\" color=\"#999999\">this application was built using <a href=\"http://www2.dmsolutions.ca/webtools/\">GMapFactory</a></font>"
    ."</td>\n"
    ."</tr>\n"
    ."<!------------------->\n"
    ."<!-- END CREDITS -->\n"
    ."<!------------------->\n"
    ."</table>\n"
    ."<!-------------------->\n"
    ."<!-- END MAIN TABLE -->\n"
    ."<!-------------------->\n"
    ."<!----------------------->\n"
    ."<!-- BEGIN HIDDEN VARS -->\n"
    ."<!----------------------->\n"
    ."<input type=\"hidden\" name=\"PrevStateKey\" value=\"<?php echo ".'$'."szCurrentState ?>\">\n";

    // set flag to not process legend if not present
    if ( $bLegend )
        $szCHBuffer .= "<input type=\"hidden\" name=\"NotFirstLoad\" value=\"1\">\n";
    else
        $szCHBuffer .="<input type=\"hidden\" name=\"NotFirstLoad\" value=\"0\">\n";

    // continue
    $szCHBuffer .= "<input type=\"hidden\" name=\"RosaMode\" value=\"$nRosaMode\">\n";

    if ( $nRosaMode == 1 )
    {
        // add hidden variable
        $szCHBuffer .= "<input type='hidden' name='ROSA_CMD'>\n";
    }

    $szCHBuffer .= "<input type=\"hidden\" name=\"INPUT_TYPE\" value=\"\">\n"
    ."<input type=\"hidden\" name=\"INPUT_COORD\" value=\"<?php if (isset(".'$'."http_form_vars['INPUT_COORD'])) echo ".'$'."http_form_vars['INPUT_COORD'] ?>\">\n"
    ."<input type=\"hidden\" name=\"QueryString\" value=\"<?php if (isset(".'$'."szQueryString)) echo ".'$'."szQueryString ?>\">\n"
    ."<!--------------------->\n"
    ."<!-- END HIDDEN VARS -->\n"
    ."<!--------------------->\n";


    // return the string
    return $szCHBuffer;

// end drawCloseHTML function
}

/**
 * This function returns a string representing the necessary HTML to draw
 * the legend
 *
 * @return string - The HTML to draw the legend.
 **/
function drawLegend()
{
    // build the string
    $szLBuffer = "<!----------------------->\n"
                ."<!-- BEGIN DRAW LEGEND -->\n"
                ."<!----------------------->\n"
                ."<tr>\n"
                ."<td align=center>\n"
                ."<table border=0 cellspacing=2 cellpadding=0>\n"
                ."<tr>\n"
                ."<td colspan=3><font face=\"Arial, Helvetica, sans-serif\" size=\"2\">"
                        ."<b>Legend</b></font></td>\n"
                ."</tr>\n"
                ."<tr>\n"
                ."<td colspan=3><font face=\"Arial, Helvetica, sans-serif\" size=\"2\">"
                        ."&nbsp;<img src=\"images/icon_eye.gif\" width=\"17\" "
                        ."height=\"11\"><b>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
                        ."&nbsp;&nbsp;&nbsp;Layer</b></font></td>\n"
                ."</tr>\n"
                ."<tr>\n"
                ."<td bgcolor=\"#999999\" colspan=3><img src=\"images/a_pixel.gif\" "
                        ."width=\"1\" height=\"1\"></td>\n"
                ."</tr>\n"
                ."<?php\n"
                ."// display the results if the processLegendTemplate() function\n"
                ."echo ".'$'."szLegendTemplate;\n"
                ."?>\n"
                ."<tr>\n"
                ."<td bgcolor=\"#999999\" colspan=3><img src=\"images/a_pixel.gif\" "
                        ."width=\"1\" height=\"1\"></TD>\n"
                ."</tr>\n"
                ."<tr>\n"
                ."<td colspan=3><input type=image src=\"images/icon_redraw.gif\" "
                        ."width=\"19\" height=\"19\" name=redraw border=0>"
                        ."<font face=\"Arial, Helvetica, sans-serif\" "
                        ."size=\"2\">&nbsp;Redraw Map</font></td>\n"
                ."</tr>\n"
                ."</table>\n"
                ."</td>\n"
                ."</tr>\n"
                ."<!--------------------->\n"
                ."<!-- END DRAW LEGEND -->\n"
                ."<!--------------------->\n";

    // return the string
    return $szLBuffer;
}

/**
 * This function generates the HTML necessary to draw the scalebar.
 *
 * @return string - HTML to draw the scalebar.
 **/
function drawScalebar()
{
    // build the string
    $szSBBuffer = "<!-------------------->\n"
                 ."<!-- BEGIN SCALEBAR -->\n"
                 ."<!-------------------->\n"
                 ."<tr>\n"
                 ."<td align=\"center\">"
                 ."<img src=<?php echo drawScalebar( ".'$'
                 ."oMapSession ) ?>"
                 ." border=0></td>\n"
                 ."</tr>\n"
                 ."<!------------------>\n"
                 ."<!-- END SCALEBAR -->\n"
                 ."<!------------------>\n";

    // return the string
    return $szSBBuffer;
}

/**
 * This function generates the HTML necessary to draw the map title.
 *
 * @param $szMapTitle string - The text to display as the title.
 * @param $nTitleSize integer - The HTML font size to use.
 * @param $nRed integer - The red rgb value for the font.
 * @param $nGreen integer - The green rgb value for the font.
 * @param $nBlue integer - The blue rgb value for the font.
 * @return string - HTML to draw the title.
 **/
function drawMapTitle($szMapTitle, $nTitleSize, $nRed, $nGreen, $nBlue)
{
    // calculate the hex equivalent of the rgbs
    $szRed = dechex($nRed);
    if ( strlen( $szRed ) == 1 ) $szRed = "0".$szRed;
    $szGreen = dechex($nGreen);
    if ( strlen( $szGreen ) == 1 ) $szGreen = "0".$szGreen;
    $szBlue = dechex($nBlue);
    if ( strlen( $szBlue ) == 1 ) $szBlue = "0".$szBlue;

    $nHexColour = $szRed.$szGreen.$szBlue;

    // build the string
    $szMTBuffer = "<!--------------------->\n"
                 ."<!-- BEGIN MAP TITLE -->\n"
                 ."<!--------------------->\n"
                 ."<tr>\n"
                 ."<td align=\"center\"><font face=\"Arial, Helvetica, "
                 ."sans-serif\" color=\"$nHexColour\" size=\"$nTitleSize\"><b>"
                 .$szMapTitle
                 ."</b></font></td>\n"
                 ."</tr>\n"
                 ."<!------------------->\n"
                 ."<!-- END MAP TITLE -->\n"
                 ."<!------------------->\n";

    // return the string
    return $szMTBuffer;
}

/**
 * This function generates the HTML necessary to draw the main map.
 *
 * @param $szSettingsFile string - The path and filiename of the settings file.
 * @return string - HTML necessary to draw the main map.
 **/
function drawMap( $szSettingsFile )
{
    // include the settings file
    include( $szSettingsFile );

    // set flag
    $bDrawPan = strtoupper($szPanArrowsType) == "SM" && $bPanArrows;

    // build the string
    $szMBuffer = "<!---------------------------->\n"
                ."<!-- BEGIN MAP & PAN ARROWS -->\n"
                ."<!---------------------------->\n"
                ."<tr>\n"
                ."<td align=\"center\">\n"
                ."<table border=\"0\" cellspacing=\"1\" cellpadding=\"0\">\n"
                ."<tr align=\"center\" valign=\"middle\">\n"
                ."<td>&nbsp;</td>\n";

    // draw pan arrows if required
    if ($bDrawPan)
    {
        // add the pan arrow string
        $szMBuffer = $szMBuffer
                    ."<td><input type=image name=Pan_North src=\"images/"
                    ."icon_pan_north.gif\" border=0 width=25 height=17></td>\n";
    }
    else
    {
        // just add a blank cell
        $szMBuffer = $szMBuffer."<td>&nbsp;</td>\n";
    }

    // continue building
    $szMBuffer = $szMBuffer
                ."<td>&nbsp;</td>\n"
                ."</tr>\n"
                ."<tr align=\"center\" valign=\"middle\">\n";

    // draw pan arrows if required
    if ($bDrawPan)
    {
        // add the pan arrow string
        $szMBuffer = $szMBuffer
                    ."<td><input type=image name=Pan_West src=\"images/"
                    ."icon_pan_west.gif\" border=0 width=17 height=25></td>\n";
    }
    else
    {
        // just add a blank cell
        $szMBuffer = $szMBuffer."<td>&nbsp;</td>\n";
    }

    // decide between ROSA and HTML
    if ( $szRadioNavType == "ROSA" )
        $nRosaFlag = 1;
    else
        $nRosaFlag = 0;

    // calculate the hex equivalent of the rgbs
    $szRed = dechex($nBorderRed);
    if ( strlen( $szRed ) == 1 ) $szRed = "0".$szRed;
    $szGreen = dechex($nBorderGreen);
    if ( strlen( $szGreen ) == 1 ) $szGreen = "0".$szGreen;
    $szBlue = dechex($nBorderBlue);
    if ( strlen( $szBlue ) == 1 ) $szBlue = "0".$szBlue;

    $nHexColour = $szRed.$szGreen.$szBlue;

    // create the tools array
    $szMBuffer .= "<?php\n".'$'."aszROSATools = array();\n";

    // if in ROSA mode then build and array of tools to include
    if ( $nRosaFlag == 1 )
    {
        // check for tools and add to the array
        if ( $bTools )
        {
            if ( $bToolsZoomIn )
                $szMBuffer .= "array_push( ".'$'."aszROSATools, \"ZOOM_IN\" );\n";
            if ( $bToolsZoomOut )
                $szMBuffer .= "array_push( ".'$'."aszROSATools, \"ZOOM_OUT\" );\n";
            if ( $bToolsZoomFull )
                $szMBuffer .= "array_push( ".'$'."aszROSATools, \"ZOOM_FULL\" );\n";
            if ( $bToolsRecentre )
                $szMBuffer .= "array_push( ".'$'."aszROSATools, \"RECENTRE\" );\n";
            if ( $bToolsQuery )
                $szMBuffer .= "array_push( ".'$'."aszROSATools, \"QUERY\" );\n";
        }
    }

    // close the php tag
    $szMBuffer .= "?>\n";

    // continue building
    $szMBuffer = $szMBuffer
                ."<td>\n"
                ."<table bgcolor=\"$nHexColour\" border=\"0\" cellspacing=\"0\" cellpadding=\"$nBorderThick\">\n"
                ."<tr>\n"
                ."<td>\n"
                ."<table width=\"100%\" border=\"0\" cellspacing=\"0\" cellpadding=\"0\">\n"
                ."<tr>\n"

                ."<!-- MAIN MAP -->\n"
                ."<?php"
                ." if (!isset(".'$'."http_form_vars[\"ROSA_CMD\"])) ".'$'."http_form_vars[\"ROSA_CMD\"] = \"\";\n"
                ." if (!isset(".'$'."http_form_vars[\"INPUT_COORD\"])) ".'$'."http_form_vars[\"INPUT_COORD\"] = \"\";\n"
                ."drawMainMap( "
                ."$nRosaFlag, ".'$'
                ."http_form_vars[\"ROSA_CMD\"], ".'$'."oMapSession, "
                .'$'."szCurrentState, ".'$'."aszROSATools , ".'$'."http_form_vars[\"INPUT_COORD\"]) ?>"

                ."</tr>\n"
                ."</table>\n"
                ."</td>\n"
                ."</tr>\n"
                ."</table>\n"
                ."</td>\n";

    // draw pan arrows if required
    if ($bDrawPan)
    {
        // add the pan arrow string
        $szMBuffer = $szMBuffer
                    ."<td><input type=image name=Pan_East src=\"images/"
                    ."icon_pan_east.gif\" border=0 width=17 height=25></td>\n";
    }
    else
    {
        // just add a blank cell
        $szMBuffer = $szMBuffer."<td>&nbsp;</td>\n";
    }

    // continue building
    $szMBuffer = $szMBuffer
                    ."</tr>\n"
                    ."<tr align=\"center\" valign=\"middle\">\n"
                    ."<td>&nbsp;</td>\n";

    // draw pan arrows if required
    if ($bDrawPan)
    {
        // add the pan arrow string
        $szMBuffer = $szMBuffer
                    ."<td><input type=image name=Pan_South src=\"images/"
                    ."icon_pan_south.gif\" border=0 width=25 height=17></td>\n";
    }
    else
    {
        // just add a blank cell
        $szMBuffer = $szMBuffer."<td>&nbsp;</td>\n";
    }

    // continue building
    $szMBuffer = $szMBuffer
                    ."<td>&nbsp;</td>\n"
                    ."</tr>\n"
                    ."</table>\n"
                    ."</td>\n"
                    ."</tr>\n"
                    ."<!-------------------------->\n"
                    ."<!-- END MAP & PAN ARROWS -->\n"
                    ."<!-------------------------->\n";

    // return the string
    return $szMBuffer;

// end of drawMap function
}

/**
 * This function generates the HTML necessary to draw a Pan Rose.
 *
 * @return  string - The HTML to draw a Pan Rose.
 **/
function drawPanRose()
{
    // build string
    $szPRBuffer = "<!-------------------->\n"
                 ."<!-- BEGIN PAN ROSE -->\n"
                 ."<!-------------------->\n"
                 ."<tr>\n"
                 ."<td><font face=\"Arial, Helvetica, sans-serif\" "
                 ."size=\"2\"><b>Pan Tool</b></font></td>\n"
                 ."</tr>\n"
                 ."<tr>\n"
                 ."<td align=\"center\">\n"
                 ."<table>\n"
                 ."<tr>\n"
                 ."<td>&nbsp;</td>\n"
                 ."<td><input type=image name=Pan_North src=\"images/"
                 ."icon_pan_north.gif\" border=0 width=25 height=17></td>\n"
                 ."<td>&nbsp;</td>\n"
                 ."</tr>\n"
                 ."<tr>\n"
                 ."<td><input type=image name=Pan_West src=\"images/"
                 ."icon_pan_west.gif\" border=0 width=17 height=25></td>\n"
                 ."<td align=\"center\"><font face=\"Arial, Helvetica, "
                         ."sans-serif\" COLOR=\"#336699\" size=\"4\">+"
                         ."</font></td>\n"
                 ."<td><input type=image name=Pan_East SRC=\"images/"
                 ."icon_pan_east.gif\" border=0 width=17 height=25></TD>\n"
                 ."</TR>\n"
                 ."<TR>\n"
                 ."<TD>&nbsp;</TD>\n"
                 ."<TD><input type=image name=Pan_South src=\"images/"
                 ."icon_pan_south.gif\" border=0 width=25 height=17></td>\n"
                 ."<td>&nbsp;</td>\n"
                 ."</tr>\n"
                 ."</table>\n"
                 ."</td>\n"
                 ."</tr>\n"
                 ."<!------------------>\n"
                 ."<!-- END PAN ROSE -->\n"
                 ."<!------------------>\n";

    // return string
    return $szPRBuffer;

}

/**
 * This function generates the HTML necessary to draw the keymap.
 *
 * @return string - HTML to draw the keymap.
 **/
function drawKeyMap()
{
    // build string
    $szKMBuffer = "<!------------------>\n"
                 ."<!-- BEGIN KEYMAP -->\n"
                 ."<!------------------>\n"
                 ."<tr>\n"
                 ."<td align=center>\n"
                 ."<table border=0 cellspacing=0 cellpadding=1>\n"
                 ."<tr>\n"
                 ."<?php echo ".'$'."szReference ?>\n"
                 ."</tr>\n"
                 ."</table>\n"
                 ."</td>\n"
                 ."</tr>\n"
                 ."<!---------------->\n"
                 ."<!-- END KEYMAP -->\n"
                 ."<!---------------->\n";

    // return the string
    return $szKMBuffer;
}

/**
 * This function generates the HTML necessary to draw the toolbar.
 *
 * @param $szSettingsFile string - The path and filename of the settings file.
 * @return string - HTML to draw the toolbar.
 **/
function drawTools( $szSettingsFile )
{
    // include the settings file
    include( $szSettingsFile );

    // initialize the tool array
    $aszTools = array();

    // build an array of tools
    if ($bToolsZoomFactor)
    {
        // add zoom factor
        array_push( $aszTools, "Z_FACTOR" );
    }

    if ($bToolsZoomIn)
    {
        // add ZOOM_IN to the array
        array_push( $aszTools, "ZOOM_IN" );
    }
    if ($bToolsZoomOut)
    {
        // add ZOOM_OUT to the array
        array_push( $aszTools, "ZOOM_OUT" );
    }
    if ($bToolsZoomFull)
    {
        // add ZOOM_FULL to the array
        array_push( $aszTools, "ZOOM_FULL" );
    }
    if ($bToolsRecentre)
    {
        // add RECENTRE to the array
        array_push( $aszTools, "RECENTRE" );
    }
    if ($bToolsQuery)
    {
        // add QUERY to the array
        array_push( $aszTools, "QUERY" );
    }

    // only draw the tools if the array is populated
    if ( count($aszTools) > 0 )
    {
        // begin to build the string
        $szTBuffer = "<!------------------------->\n"
                    ."<!-- BEGIN MAPPING TOOLS -->\n"
                    ."<!------------------------->\n"
                    ."<tr>\n"
                    ."<td align=center>\n"
                    ."<table border=0 cellspacing=2 cellpadding=0>\n"
                    ."<tr>\n"
                    ."<td><font face=\"Arial, Helvetica, sans-serif\" "
                    ."size=\"2\"><b>Map Tools</b></font></td>\n"
                    ."</tr>\n"
                    ."<tr>\n"
                    ."<td align=\"center\">\n";

        // calculate the column and cell arrangement
        $nRows = intval(ceil(count($aszTools)/$nToolsColumns));

        // open the table tag
        $szTBuffer = $szTBuffer
                     ."<table border=\"0\" cellspacing=\"0\" "
                     ."cellpadding=\"1\">\n";

        // reset the array pointer
        reset ($aszTools);

        // loop and create a new row for each item in the array
        for ($i = 0; $i < $nRows; $i++)
        {
            // open new row
            $szTBuffer = $szTBuffer."<tr>\n";

            // loop for each column
            for ($j = 0; $j < $nToolsColumns; $j++)
            {
                //only process while array items exist
                if (($i+($j * $nRows)) < count($aszTools))
                {
                    // create the string
                    if ($aszTools[($i+($j * $nRows))] == "Z_FACTOR")
                    {
                        // add the cell
                        $szTBuffer = $szTBuffer
                                    ."<td colspan=2 align=right><input type=\"textbox\" name="
                                    ."\"txtZoomFactor\" value=\"<?php if "
                                    ."( strlen(trim(".'$'."http_form_vars[\""
                                    ."txtZoomFactor\"])) > 0 ) echo "
                                    .'$'."http_form_vars[\"txtZoomFactor\"]; else "
                                    ."echo $nZoomFactor; ?>\" size=\"3\"></td>"
                                    ."<td><font face=\"Arial, Helvetica, "
                                    ."sans-serif\" size=\"1\">&nbsp;Zoom "
                                    ."Factor&nbsp;&nbsp;</font></td>\n";
                    }
                    elseif ($aszTools[($i+($j * $nRows))] == "ZOOM_IN")
                    {
                        // add the cell
                        $szTBuffer = $szTBuffer
                            ."<td><input type=\"radio\" name=\"ROSA_CMD\" "
                            ."value=\"ZOOM_IN\" <?php if ( (".'$'
                            ."http_form_vars[\"ROSA_CMD\"] == \"ZOOM_IN\") || "
                            ."( strlen(trim(".'$'."http_form_vars[\""
                            ."ROSA_CMD\"])) <= 0 ) || (substr(".'$'."http_form_vars[\"ROSA_CMD\"],0,3) == \"PAN\")) "
                            ."echo \"CHECKED\" ?>></td>"
                            ."<td bgcolor=\"#DFF5F5\"><INPUT TYPE=IMAGE name=Zoom_In SRC=\"images/icon_zoomin.gif\" "
                            ."width=\"22\" "
                            ."height=\"22\" border=\"0\"></td><td><font face=\"Arial, "
                            ."Helvetica, sans-serif\" size=\"1\">&nbsp;Zoom In"
                            ."&nbsp;&nbsp;</font></td>";
                    }
                    elseif ($aszTools[($i+($j * $nRows))] == "ZOOM_OUT")
                    {
                        // add the cell
                        $szTBuffer = $szTBuffer
                            ."<td><input type=\"radio\" name=\"ROSA_CMD\" "
                            ."value=\"ZOOM_OUT\" <?php if ( ".'$'
                            ."http_form_vars[\"ROSA_CMD\"] == \"ZOOM_OUT\") "
                            ."echo \"CHECKED\" ?>></td><td bgcolor=\"#DFF5F5\">"
                            ."<INPUT TYPE=IMAGE name=Zoom_Out SRC=\"images/icon_zoomout.gif\" "
                            ."width=\"22\" "
                            ."height=\"22\" border=\"0\"></td><td><font face=\"Arial, "
                            ."Helvetica, sans-serif\" size=\"1\">&nbsp;Zoom Out"
                            ."&nbsp;&nbsp;</font></td>";
                    }
                    elseif ($aszTools[($i+($j * $nRows))] == "ZOOM_FULL")
                    {
                        // add the cell
                        $szTBuffer = $szTBuffer
                            ."<td><input type=\"radio\" name=\"ROSA_CMD\" "
                            ."value=\"ZOOM_FULL\" <?php if ( ".'$'
                            ."http_form_vars[\"ROSA_CMD\"] == \"ZOOM_FULL\") "
                            ."echo \"CHECKED\" ?>></td><td bgcolor=\"#DFF5F5\">"
                            ."<INPUT TYPE=IMAGE name=Zoom_Full SRC=\"images/"
                            ."icon_fullextent.gif\" width=\"22\" "
                            ."height=\"22\" border=\"0\"></td><td><font face=\"Arial, "
                            ."Helvetica, sans-serif\" size=\"1\">&nbsp;Full Extents"
                            ."&nbsp;&nbsp;</font></td>";
                    }
                    elseif ($aszTools[($i+($j * $nRows))] == "RECENTRE")
                    {
                        // add the cell
                        $szTBuffer = $szTBuffer
                            ."<td><input type=\"radio\" name=\"ROSA_CMD\" "
                            ."value=\"RECENTRE\" <?php if ( ".'$'
                            ."http_form_vars[\"ROSA_CMD\"] == \"RECENTRE\") "
                            ."echo \"CHECKED\" ?>></td><td bgcolor=\"#DFF5F5\">"
                            ."<img name=Recentre SRC=\"images/"
                            ."icon_recentre.gif\" width=\"22\" "
                            ."height=\"22\" border=\"0\"></td><td><font face=\"Arial, "
                            ."Helvetica, sans-serif\" size=\"1\">&nbsp;Recentre"
                            ."&nbsp;&nbsp;</font></td>";
                    }
                    elseif ($aszTools[($i+($j * $nRows))] == "QUERY")
                    {
                        // add the cell
                        $szTBuffer = $szTBuffer
                            ."<td><input type=\"radio\" name=\"ROSA_CMD\" "
                            ."value=\"QUERY\" <?php if ( ".'$'
                            ."http_form_vars[\"ROSA_CMD\"] == \"QUERY\") "
                            ."echo \"CHECKED\" ?>></td><td bgcolor=\"#DFF5F5\">"
                            ."<img name=Query SRC=\"images/"
                            ."icon_query.gif\" width=\"22\" "
                            ."height=\"22\" border=\"0\"></td><td><font face=\"Arial, "
                            ."Helvetica, sans-serif\" size=\"1\">&nbsp;Query"
                            ."&nbsp;&nbsp;</font></td>";
                    }
                }
                else
                {
                    // return blank cell
                    $szTBuffer = $szTBuffer."<td>&nbsp;</td>\n";
                }

            // end column for loop
            }

            // close the row
            $szTBuffer = $szTBuffer."</tr>\n";

        // end row for
        }

        //close the table and tools
        $szTBuffer = $szTBuffer
                    ."</table>\n"
                    ."</td>\n"
                    ."</tr>\n"
                    ."</table>\n"
                    ."</td>\n"
                    ."</tr>\n"
                    ."<!----------------------->\n"
                    ."<!-- END MAPPING TOOLS -->\n"
                    ."<!----------------------->\n";

    }

    // Return the string
    return $szTBuffer;

}


/**
 * This function returns the HTML string to draw a horizontal divider.
 *
 * @return string - The string to draw the divider.
 **/
function drawDivider()
{
    // build string
    $szDBuffer = "<tr>\n"
                ."<td><hr noshade size=1></td>\n"
                ."</tr>\n";

    // return the string
    return $szDBuffer;

// end drawDivider function
}

/**
 * This function builds an array of object names according to columns and
 * position.
 *
 * @param $nColumn integer - Column number.
 * @param $szSettingsFile string - The path and filename of the settings file.
 * @param $oLog object - The log file object.
 * @return array - An array of object names indexed according to position.
 **/
function buildDrawOrderArray($nColumn, $szSettingsFile, $oLog)
{
    // log entry into function
    $oLog->logFuncStart( LOG_VERBOSE, "Begin buildDrawOrderArray() function." );

    // get variables
    include( $szSettingsFile );

    // initialize the return array
    $aszReturn = array();

    // check main map and add it to the array if in the required column
    if ($nMapPosition == $nColumn) $aszReturn[$nMapOrder] = "MAP";

    // check map title
    if ($bTitle && $nTitPosition == $nColumn)
                                        $aszReturn[$nTitOrder] = "TITLE";
    // check legend
    if ($bLegend && $nLegPosition == $nColumn)
                                        $aszReturn[$nLegOrder] = "LEGEND";
    // check scalebar
    if ($bScaleBar && $nScaPosition == $nColumn)
                                        $aszReturn[$nScaOrder] = "SCALEBAR";
    // check keymap
    if ($bKeyMap && $nKeyPosition == $nColumn)
                                        $aszReturn[$nKeyOrder] = "KEYMAP";
    // check mapping tools
    if ($bTools && ($nTooPosition == $nColumn) &&
        (strtoupper($szRadioNavType) == "HTML"))
                                        $aszReturn[$nTooOrder] = "TOOLS";
    // check pan rose
    if ($bPanArrows && ($nPanPosition == $nColumn) &&
        (strtoupper($szPanArrowsType) == "CR"))
                                        $aszReturn[$nPanOrder] = "PAN";

    // log the contents of the array
    $oLog->log( LOG_QUIET, $aszReturn );

    // log exit
    $oLog->logFuncEnd( LOG_VERBOSE, "End buildDrawOrderArray() function." );

    // return array
    return $aszReturn;

// end buildDrawOrderArray function
}

/**
 * This function returns the string to draw the requested object.
 *
 * @param $szObject string - The name of the object to draw.
 * @param $oLog object - The log file object.
 * @param $szSettingsFile string - The settings file.
 * @return string - The HTML string of the object requested.
 **/
function drawObject($szObject, $oLog, $szSettingsFile)
{
    // record start
    $oLog->logFuncStart( LOG_VERBOSE, "Begin drawObject() function." );

    // include the settings file
    include( $szSettingsFile );

    // initialize the buffer
    $szDOBuffer = "";

    // draw the requested object
    switch ($szObject)
    {
    case "MAP":
        $oLog->log( LOG_QUIET, "Draw Map." );
        $szDOBuffer = drawMap($szSettingsFile);
        break;
    case "TITLE":
        $oLog->log( LOG_QUIET, "Draw Title." );
        $szDOBuffer = drawMapTitle($szTitle, $nTitleSize, $nTitleRed,
                                                $nTitleGreen, $nTitleBlue);
        break;
    case "LEGEND":
        $oLog->log( LOG_QUIET, "Draw Legend." );
        $szDOBuffer = drawLegend();
        break;
    case "SCALEBAR":
        $oLog->log( LOG_QUIET, "Draw Scalebar." );
        $szDOBuffer = drawScalebar();
        break;
    case "KEYMAP":
        $oLog->log( LOG_QUIET, "Draw Keymap." );
        $szDOBuffer = drawKeyMap();
        break;
    case "TOOLS":
        $oLog->log( LOG_QUIET, "Draw Tools." );
        $szDOBuffer = drawTools( $szSettingsFile );
        break;
    case "PAN":
        $oLog->log( LOG_QUIET, "Draw Pan." );
        $szDOBuffer = drawPanRose();
        break;
    }

    // record end
    $oLog->logFuncEnd( LOG_VERBOSE, "End drawObject() function." );

    // return the string
    return $szDOBuffer;

// end drawObject function
}

function drawPreviewPage( $szAppName, $szAppDir ,$szMapTitle )
{
    // build the page names
    $szPhtmlPage = $szAppDir.$szAppName.".phtml";
    $szPhpPage = "./".$szAppName.".php";
    $szContentsPage = "./".$szAppName."_contents.php";

    // build the string to return
    $szBuffer =
"<?php\n".
"/**\n".
" * @author      GMapFactory\n".
" * @contact     DM Solutions Group Inc. (www.dmsolutions.ca)\n".
" * @copyright\n".
" * <b>Copyright (c) 2002, DM Solutions Group Inc.</b>\n".
" * Permission is hereby granted, free of charge, to any person obtaining a\n".
" * copy of this software and associated documentation files (the \"Software\"),\n".
" * to deal in the Software without restriction, including without limitation\n".
" * the rights to use, copy, modify, merge, publish, distribute, sublicense,\n".
" * and/or sell copies of the Software, and to permit persons to whom the\n".
" * Software is furnished to do so, subject to the following conditions:\n".
" * \n".
" * The above copyright notice and this permission notice shall be included\n".
" * in all copies or substantial portions of the Software.\n".
" * \n".
" * THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n".
" * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\n".
" * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL\n".
" * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\n".
" * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING\n".
" * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER\n".
" * DEALINGS IN THE SOFTWARE.\n".
" * \n".
" */\n".
"\n".
"// include the supporting php routines \n".
"include_once( \"$szPhpPage\" );\n".
"?>\n".
"<html>\n".
"<head>\n".
"<title>$szMapTitle</title>\n".
"<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\n".
"<script language=\"javascript\">\n".
"/**\n".
" * This function runs after the form is done loading\n".
" **/\n".
"function doneLoading()\n".
"{\n".
"    // show the query results page if query\n".
"    if ( document.main.QueryString.value != \"\" )\n".
"    {\n".
"        // complete the string\n".
"        document.main.QueryString.value = \"?PrevStateKey=\" + document.main.PrevStateKey.value + \"&INPUT_COORD=\" + document.main.INPUT_COORD.value;\n".
"\n".
"        // calculate the center\n".
"        if (document.all)\n".
"            var xMax = screen.width, yMax = screen.height;\n".
"        else if (document.layers)\n".
"            var xMax = window.outerWidth, yMax = window.outerHeight;\n".
"        else\n".
"            var xMax = 640, yMax=480;\n".
"\n".
"        var xOffset = (xMax - 510)/2, yOffset = (yMax - 390)/2;\n".
"\n".
"        // load the processing page\n".
"        mapquery = window.open('query.phtml' + document.main.QueryString.value,'mapquery','scrollbars=yes,resizable=yes,width=510,height=390,screenX='+xOffset+',screenY='+yOffset+',top='+yOffset+',left='+xOffset+'');\n".
"\n".
"        // give it focus\n".
"        mapquery.focus();\n".
"\n".
"    }\n".
"\n".
"    // exit\n".
"    return;\n".
"}\n".
"</script>\n".
"</head>\n".
"<body onload=\"javascript:doneLoading()\" bgcolor=\"ffffff\">\n".
"<form name=\"main\">\n".
"<!-------------------------------------->\n".
"<!-- !!!DO NOT MODIFY THIS SECTION!!! -->\n".
"<!-------------------------------------->\n".
"<?php include_once( \"$szContentsPage\" ); ?>\n".
"<!-------------------------------------->\n".
"<!-------------------------------------->\n".
"</form>\n".
"</body>\n".
"</html>\n";

    // open the file
    $fPHTML = fopen($szPhtmlPage, 'w');

    // write the buffer
    fwrite($fPHTML, $szBuffer);

    // close the file
    fclose($fPHTML);

    // return success
    return true;

// end drawPrevirePage function
}

/**
 * This function write the globprefs file based on the sipplied parameters.
 *
 * @param $szGlobprefsFile string - The path and filename of the file to create.
 * @param $szAppPath string - The Path and filename of the main application.
 * @param $szSettingsFile string - The path and filename of the settings file.
 * @param $szMapFile string - The path and filename of the map file.
 * @param $szMapscriptModule string - Mapscript module name.
 * @param $oLog object - The log object.
 * @return boolean - True if successful, False if not.
 **/
function drawGlobprefs( $szGlobprefsFile, $szAppPath, $szSettingsFile,
                                      $szMapFile, $szMapscriptModule , $oLog )
{
    // log the start
    $oLog->logFuncStart( LOG_VERBOSE, "Begin drawGlobprefs() function." );

    // include the settings file
    include ( $szSettingsFile );

    // ensure that the mapscript module is loaded
    loadModules();

    // create a new mapscript object
    $oMap = ms_newMapObj( $szMapFile );

    // create the buffer string
    $szBuffer =
"<?php\n".
"/**\n".
" * @author      GMapFactory\n".
" * @contact     DM Solutions Group Inc. (www.dmsolutions.ca)\n".
" * @copyright\n".
" * <b>Copyright (c) 2002, DM Solutions Group Inc.</b>\n".
" * Permission is hereby granted, free of charge, to any person obtaining a\n".
" * copy of this software and associated documentation files (the \"Software\"),\n".
" * to deal in the Software without restriction, including without limitation\n".
" * the rights to use, copy, modify, merge, publish, distribute, sublicense,\n".
" * and/or sell copies of the Software, and to permit persons to whom the\n".
" * Software is furnished to do so, subject to the following conditions:\n".
" * \n".
" * The above copyright notice and this permission notice shall be included\n".
" * in all copies or substantial portions of the Software.\n".
" * \n".
" * THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n".
" * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\n".
" * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL\n".
" * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\n".
" * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING\n".
" * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER\n".
" * DEALINGS IN THE SOFTWARE.\n".
" * \n".
" */\n".
"\n".
"// the application root directory\n".
"define( \"APP_PATH\", \"".$szAppPath."\" );\n".

"\n".
"// define a temp directory to write temp files \n".
"// directory must be writeable\n".
"define( \"TMP_DIR\", APP_PATH.\"tmp/\" );\n".
"\n".
"// define the map file to be used in this application\n".
"define( \"MAPFILE\", \"$szMapFile\" );\n".
"\n".
"// define the height and width of the map\n".
"define( \"MAP_WIDTH\", \"".$oMap->width."\" );\n".
"define( \"MAP_HEIGHT\", \"".$oMap->height."\" );\n".
"\n".
"// define the height and width of the keymap\n".
"define( \"KEYMAP_WIDTH\", \"".$oMap->reference->width."\" );\n".
"define( \"KEYMAP_HEIGHT\", \"".$oMap->reference->height."\" );\n".
"\n".
"// define the maximum extents\n".
"define( \"MAX_EXT_MINX\", ".$oMap->extent->minx." );\n".
"define( \"MAX_EXT_MINY\", ".$oMap->extent->miny." );\n".
"define( \"MAX_EXT_MAXX\", ".$oMap->extent->maxx." );\n".
"define( \"MAX_EXT_MAXY\", ".$oMap->extent->maxy." );\n".
"\n".
"// define the path and filename of the ROSA applet (must be relative)\n".
"define( \"ROSA_FILE\", \"./rosa/rosa.jar\" );\n".
"\n".
"// define the zoom out factor to be used\n".
"define( \"ZOOMOUT_FACTOR\", $nZoomFactor );\n".
"\n".
"// define the zoom in factor to be used\n".
"define( \"ZOOMIN_FACTOR\", $nZoomFactor );\n".
"\n".
"// define the default IMAGEURL & PATH\n".
'$'."gDefaultImagePath = \"".$_SESSION["gszTmpImgPath"]."\";\n".
'$'."gDefaultImageURL = \"".$_SESSION["gszTmpWebImgPath"]."\";\n".
"\n".
"// define the smallest rectangle size (in pixels) for zooming in, \n".
"// otherwise treat as a point\n".
"define( \"MIN_RECT\", 5 );\n".
"\n".
"// include the utilties file for misc functions\n".
"include_once( APP_PATH.\"wrapper/utilities.php\" );\n".
"include_once( APP_PATH.\"logger/logfile.php\" );\n".
"include_once( APP_PATH.\"logger/error_manager.php\" );\n".
"include_once( APP_PATH.\"logger/logger.php\" );\n".
"include_once( APP_PATH.\"wrapper/map_session.php\" );\n".
"include_once( APP_PATH.\"wrapper/map_navigator.php\" );\n".
"include_once( APP_PATH.\"wrapper/map_query.php\" );\n".
"\n".
"// create new logfile object (customize parameters)\n".
'$'."gLogFile = new LogFile(TMP_DIR.\"log.txt\", LOG_TO_FILE, 1);\n".
"\n".
"// set the max log level (adjust as necessary)\n".
'$'."gLogFile->setMaxLogLevel( LOG_OFF );\n".
"\n".
"// create new error manager object\n".
'$'."gErrorManager = new ErrorManager();\n".
"\n".
"// create a new map session object\n".
'$'."oMapSession = new MapSession_R;\n".
"\n".
"// set the global log file and error manager\n".
'$'."oMapSession->setLogFile( ".'$'."gLogFile );\n".
'$'."oMapSession->setErrorManager( ".'$'."gErrorManager );\n".
"\n".
"// set the temp directory for the map session\n".
'$'."oMapSession->setTempDir( TMP_DIR );\n".
"\n".
"// set the maximum extents to limit navigation\n".
'$'."oMapSession->setMaxExtents( MAX_EXT_MINX, MAX_EXT_MINY, MAX_EXT_MAXX, \n".
"                                                           MAX_EXT_MAXY );\n".
"// create a new map navigator object\n".
'$'."oMapNavigator = new MapNavigator( ".'$'."oMapSession );\n".
"\n".
"// set the global log file and error manager\n".
'$'."oMapNavigator->setLogFile( ".'$'."gLogFile );\n".
'$'."oMapNavigator->setErrorManager( ".'$'."gErrorManager );\n".
"\n".
"// create a new map query object\n".
'$'."oMapQuery = new MapQuery( ".'$'."oMapSession );\n".
"\n".
"// set the global log file and error manager\n".
'$'."oMapQuery->setLogFile( ".'$'."gLogFile );\n".
'$'."oMapQuery->setErrorManager( ".'$'."gErrorManager );\n".
"\n".
"/* ============================================================================\n".
" * Load the mapscript module\n".
" * ========================================================================= */\n".
'$'."szModule = \"$szMapscriptModule\";\n".
"define( \"MS_MODULE\", \"$szMapscriptModule\" );\n".
"\n".
"// ensure that the mapscript module is loaded (using function from utilties.php)\n".
"load_module( \"MapScript\", ".'$'."szModule );\n".
"\n".
"?>\n";

    // open the file
    $fGlob = fopen( $szGlobprefsFile, 'w' );

    // write the buffer
    fwrite( $fGlob, $szBuffer );

    // close the file
    fclose( $fGlob );

    // log the end
    $oLog->logFuncEnd( LOG_VERBOSE, "End drawGlobprefs() function." );

    // return success
    return true;

// end drawGlobprefs function
}

/**
 * This function ensures that the MapScript module is loaded
 *
 **/
function loadModules()
{
    global $gszMapscriptModule;

    // ensure that the mapscript module is loaded
    if (!extension_loaded("MapScript")) dl($gszMapscriptModule);

// end of loadModules function
}
?>
