<?php
/**
 * GMapFactory application
 *
 * @project     MapLab
 * @revision    $Id: params.php,v 1.21.2.1 2004/07/15 19:34:56 zak Exp $
 * @purpose     This is the main frames page.
 * @author      William A. Bronsema, C.E.T. (bronsema@dmsolutions.ca)
 * @copyright
 * <b>Copyright (c) 2002, DM Solutions Group Inc.</b>
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

/*****************************************************************************
 * $Log: params.php,v $
 * Revision 1.21.2.1  2004/07/15 19:34:56  zak
 * stopped undefined var warnings
 *
 * Revision 1.21  2002/07/08 12:21:26  pspencer
 * fixed update of color button
 *
 * Revision 1.20  2002/07/05 16:44:41  bronsema
 * Fixed grouped legend not being maintained when re-loading into
 * GMapFactory
 *
 * Revision 1.19  2002/07/03 14:11:51  bronsema
 * switched alias function "sizeof" to proper function "count"
 *
 * Revision 1.18  2002/06/28 03:15:37  bronsema
 * Updated to new session variable handler
 *
 * Revision 1.17  2002/06/13 14:13:52  sacha
 * Change copywrite msg
 *
 * Revision 1.16  2002/06/12 18:47:58  bronsema
 * Added grouped layer option for the legend
 *
 * Revision 1.15  2002/06/12 12:17:18  bronsema
 * Added new parameter to title check
 *
 * Revision 1.14  2002/06/12 11:51:43  bronsema
 * Updated to update page title to map title only if previous page title is "Untitled"
 *
 * Revision 1.13  2002/06/11 19:20:29  bronsema
 * Defaults navigation mode as set in XML config.
 *
 * Revision 1.12  2002/05/09 11:44:43  bronsema
 * Fixed bug 992 - The legend check boxes were being processed when
 * legend was off resulting in all layers being turned off.
 *
 * Revision 1.11  2002/05/06 12:03:42  bronsema
 * Updated path information to reflect changes in application structure
 *
 * Revision 1.10  2002/05/02 13:44:05  bronsema
 * Completed functionality to allow quick loading of previous projects
 *****************************************************************************/

/* ============================================================================
 * HTTP_FORM_VARS array contains the HTTP GET or POST parameters
 * ========================================================================= */
$http_form_vars = count( $_POST ) > 0 ? $_POST :
                                    ( count($_GET) > 0 ? $_GET : array("") );

//foreach ( $http_form_vars as $key=>$value )
//  echo "$key=$value";

/* ============================================================================
 * Re-build the settings file if necessary
 * ========================================================================= */
// create the setting file with defaults if not found
if(!file_exists( $http_form_vars["gszWorkingDir"]."settings.php" ) )
{
    // create and default
    DefaultSettings( $http_form_vars["gszWorkingDir"]."settings.php",
                     strval( $http_form_vars["gszMapFile"] ), $gszDefaultMode );
}
// update the settings file only if the form has been submitted
elseif ( $http_form_vars["submitted"] )
{
    // determine if default button has been pressed
    if ($http_form_vars["txtDefault"] == "YES")
    {
        // default
        DefaultSettings( $http_form_vars["gszWorkingDir"]."settings.php",
                    strval( $http_form_vars["gszMapFile"] ), $gszDefaultMode );
    }
    else
    {
        // file has been submitted so re-write the setting file
        WriteSettings( $http_form_vars["gszWorkingDir"]."settings.php",
                    $http_form_vars, strval( $http_form_vars["gszMapFile"] ) );
    }
}

// include the setting file
include_once( $http_form_vars["gszWorkingDir"]."settings.php" );

/* ============================================================================
 * Generate the border color source image string
 * ========================================================================= */
$szBorderColorImageSource = "color.php?red=".$nBorderRed.
                             "&green=".$nBorderGreen.
                             "&blue=".$nBorderBlue."&x=30&y=20";
/* ============================================================================
 * Generate the title color source image string
 * ========================================================================= */
$szTitleColorImageSource = "color.php?red=".$nTitleRed.
                             "&green=".$nTitleGreen.
                             "&blue=".$nTitleBlue."&x=30&y=20";

/* ============================================================================
 * Re-build the phtml file
 * ========================================================================= */
include_once($gszAppPath."htdocs/gmapfactory/build_phtml.php");

/* ============================================================================
 * Update the page title if necessary
 * ========================================================================= */
if ( isset($http_form_vars["szTitle"]) && trim($http_form_vars["szTitle"]) != "Untitled" )
    checkTitle( $http_form_vars["gszAppDir"].$http_form_vars["gszAppName"].
                                                   ".phtml", $http_form_vars );

/* ============================================================================
 * Copy the correct legend template
 * ========================================================================= */
if ( file_exists( $http_form_vars["gszAppDir"]."/legend_template.html" ) )
    unlink( $http_form_vars["gszAppDir"]."/legend_template.html" );

// copy the tempate over
if ((isset ($http_form_vars["chkLegendGrp"]) &&
    $http_form_vars["chkLegendGrp"] == "on") || $bLegendGrp )
{
    // copy the group template
    copy( TEMPLATES."app_legend_template_grp.html",
                        $http_form_vars["gszAppDir"]."/legend_template.html" );
}
else
{
    // copy the layer template
    copy( TEMPLATES."app_legend_template.html",
                        $http_form_vars["gszAppDir"]."/legend_template.html" );
}

/**
 * This function builds writes the setting parameters out to a file to be used
 * in when building the preview.
 *
 * @param $szFile string - The path and filename of the settings file.
 * @param $aszURL array - The form URL to read settings from.
 * @param $szMapFile string - The path and filename of the map file.
 **/
function WriteSettings($szFile, $aszURL, $szMapFile)
{
    // open the file
    $fp = fopen($szFile, 'w');

    // calculate MapTitle boolean value
    if($aszURL["chkMapTitle"]=="on") $bchkMapTitle = "True";
                                else $bchkMapTitle = "False";

    // calculate Legend boolean value
    if($aszURL["chkLegend"]=="on") $bchkLegend = "True";
                                else $bchkLegend = "False";

    // calculate Legend boolean value
    if($aszURL["chkLegendGrp"]=="on") $bchkLegendGrp = "True";
                                else $bchkLegendGrp = "False";

    // calculate ScaleBar boolean value
    if($aszURL["chkScaleBar"]=="on") $bchkScaleBar = "True";
                                else $bchkScaleBar = "False";

    // calculate KeyMap boolean value
    if($aszURL["chkKeyMap"]=="on") $bchkKeyMap = "True";
                                else $bchkKeyMap = "False";

    // calculate Toolbar boolean value
    if($aszURL["chkMappingTools"]=="on") $bchkTools = "True";
                                else $bchkTools = "False";

    // calculate Zoom Factor boolean value
    if($aszURL["chkZoomFactor"]=="on") $bchkZoomFactor = "True";
                                else $bchkZoomFactor = "False";

    // calculate ZoomIn boolean value
    if($aszURL["chkZoomIn"]=="on") $bchkZoomIn = "True";
                                else $bchkZoomIn = "False";

    // calculate ZoomOut boolean value
    if($aszURL["chkZoomOut"]=="on") $bchkZoomOut = "True";
                                else $bchkZoomOut = "False";

    // calculate ZoomFull boolean value
    if($aszURL["chkZoomFull"]=="on") $bchkZoomFull = "True";
                                else $bchkZoomFull = "False";

    // calculate Recentre boolean value
    if($aszURL["chkRecentre"]=="on") $bchkRecentre = "True";
                                else $bchkRecentre = "False";

    // calculate Query boolean value
    if($aszURL["chkQuery"]=="on") $bchkQuery = "True";
                                else $bchkQuery = "False";
    // calculate Pan boolean value
    if($aszURL["chkPan"]=="on") $bchkPan = "True";
                                else $bchkPan = "False";

    // build buffer
    $szBuffer = "<?php\n"

                // add the map file for later reference
                ."// map file for project managment purposes\n"
                ."//$szMapFile\n\n"

                ."// set variables\n"

                // main map
                ."// Main Map\n"
                .'$nBorderThick'." = ".$aszURL["nBorderThick"].";\n"
                .'$nBorderRed'." = ".$aszURL["nBorderRed"].";\n"
                .'$nBorderGreen'." = ".$aszURL["nBorderGreen"].";\n"
                .'$nBorderBlue'." = ".$aszURL["nBorderBlue"].";\n"
                .'$nMapPosition'." = ".$aszURL["nMapPosition"].";\n"
                .'$nMapOrder'." = ".$aszURL["nMapOrder"].";\n"

                // map title
                ."// Map Title\n"
                .'$bTitle'." = ".$bchkMapTitle.";\n"
                .'$szTitle'." = \"".$aszURL["szTitle"]."\";\n"
                .'$nTitleSize'." = ".$aszURL["nTitleSize"].";\n"
                .'$nTitleRed'." = ".$aszURL["nTitleRed"].";\n"
                .'$nTitleGreen'." = ".$aszURL["nTitleGreen"].";\n"
                .'$nTitleBlue'." = ".$aszURL["nTitleBlue"].";\n"
                .'$nTitPosition'." = ".$aszURL["nTitPosition"].";\n"
                .'$nTitOrder'." = ".$aszURL["nTitOrder"].";\n"

                // legend
                ."// Legend\n"
                .'$bLegend'." = ".$bchkLegend.";\n"
                .'$bLegendGrp'." = ".$bchkLegendGrp.";\n"
                .'$nLegPosition'." = ".$aszURL["nLegPosition"].";\n"
                .'$nLegOrder'."= ".$aszURL["nLegOrder"].";\n"

                // scalebar
                ."// ScaleBar\n"
                .'$bScaleBar'." = ".$bchkScaleBar.";\n"
                .'$szScaleBarSize'." = \"".$aszURL["szScaleBarSize"]."\";\n"
                .'$nScaPosition'." = ".$aszURL["nScaPosition"].";\n"
                .'$nScaOrder'."= ".$aszURL["nScaOrder"].";\n"

                // keymap
                ."// KeyMap\n"
                .'$bKeyMap'." = ".$bchkKeyMap.";\n"
                .'$nKeyPosition'." = ".$aszURL["nKeyPosition"].";\n"
                .'$nKeyOrder'."= ".$aszURL["nKeyOrder"].";\n"

                // map tools
                ."// Map Tools\n"
                .'$szRadioNavType'." = \"".$aszURL["szRadioNavType"]."\";\n"
                .'$bToolsZoomFactor'." = ".$bchkZoomFactor.";\n"
                .'$bTools'." = ".$bchkTools.";\n"
                .'$bToolsZoomIn'." = ".$bchkZoomIn.";\n"
                .'$bToolsZoomOut'." = ".$bchkZoomOut.";\n"
                .'$bToolsZoomFull'." = ".$bchkZoomFull.";\n"
                .'$bToolsRecentre'." = ".$bchkRecentre.";\n"
                .'$bToolsQuery'." = ".$bchkQuery.";\n"
                .'$nToolsColumns'." = ".$aszURL["nToolsColumns"].";\n"
                .'$nTooPosition'." = ".$aszURL["nTooPosition"].";\n"
                .'$nTooOrder'."= ".$aszURL["nTooOrder"].";\n"
                .'$nZoomFactor'."= ".$aszURL["nZoomFactor"].";\n"

                // pan arrows
                ."// Pan Arrows\n"
                .'$bPanArrows'." = ".$bchkPan.";\n"
                .'$szPanArrowsType'." = \"".$aszURL["PanType"]."\";\n"
                .'$nPanPosition'." = ".$aszURL["nPanPosition"]
                                                                       ."; \n"
                .'$nPanOrder'."= ".$aszURL["nPanOrder"].";\n"
                ."?>";

    // write the default settings
    fwrite($fp, $szBuffer);

    // close the file
    fclose($fp);

//end WriteSettings function
}

/**
 * This function writes the default settings to the specified settings file.
 *
 * @param $szFile string - The path and filename of the settings file.
 * @param $szMapFile string - The path and filename of the map file.
 * @param $szDefaultMode string - Default navigation mode - HTML or ROSA.
 **/
function DefaultSettings( $szFile, $szMapFile, $szDefaultMode )
{
    // open the file
    $fp = fopen($szFile, 'w');

    // create the defaults
    $szBuffer = "<?php\n"
                // add the map file for later reference
                ."// map file for project managment purposes\n"
                ."//$szMapFile\n\n"

                ."// set variables\n"

                // main map
                ."// Main Map\n"
                .'$nBorderThick'." = 2;\n"
                .'$nBorderRed'." = 0;\n"
                .'$nBorderGreen'." = 0;\n"
                .'$nBorderBlue'." = 127;\n"
                .'$nMapPosition'." = 1;\n"
                .'$nMapOrder'." = 1;\n"

                // map title
                ."// Map Title\n"
                .'$bTitle'." = True;\n"
                .'$szTitle'." = \"Untitled\";\n"
                .'$nTitleSize'." = 3;\n"
                .'$nTitleRed'." = 0;\n"
                .'$nTitleGreen'." = 0;\n"
                .'$nTitleBlue'." = 127;\n"
                .'$nTitPosition'." = 1;\n"
                .'$nTitOrder'." = 0;\n"

                // legend
                ."// Legend\n"
                .'$bLegend'." = True;\n"
                .'$bLegendGrp'." = False;\n"
                .'$nLegPosition'." = 0;\n"
                .'$nLegOrder'."= 0;\n"

                // scalebar
                ."// ScaleBar\n"
                .'$bScaleBar'." = True;\n"
                .'$szScaleBarSize'." = \"MS_SMALL\";\n"
                .'$nScaPosition'." = 1;\n"
                .'$nScaOrder'."= 2;\n"

                // keymap
                ."// KeyMap\n"
                .'$bKeyMap'." = True;\n"
                .'$nKeyPosition'." = 2;\n"
                .'$nKeyOrder'."= 0;\n"

                // map tools
                ."// Map Tools\n"
                .'$szRadioNavType'." = \"$szDefaultMode\";\n"
                .'$bTools'." = True;\n"
                .'$bToolsZoomFactor'." = True;\n"
                .'$bToolsZoomIn'." = True;\n"
                .'$bToolsZoomOut'." = True;\n"
                .'$bToolsZoomFull'." = True;\n"
                .'$bToolsRecentre'." = True;\n"
                .'$bToolsQuery'." = True;\n"
                .'$nToolsColumns'." = 1;\n"
                .'$nTooPosition'." = 2;\n"
                .'$nTooOrder'."= 1;\n"
                .'$nZoomFactor'."= 2;\n"

                 // pan arrows
                ."// Pan Arrows\n"
                .'$bPanArrows'." = True;\n"
                .'$szPanArrowsType'." = \"SM\";\n"
                .'$nPanPosition'." = 2;\n"
                .'$nPanOrder'."= 2;\n"
                ."?>";

    // write the default settings
    fwrite( $fp, $szBuffer );

    // close the file
    fclose( $fp );

  //end DefaultSettings function
}

function checkTitle( $szFile, $URL )
{
    if ( !isset($URL["szTitle"]) || $URL["szTitle"] == "" )
        return;

    // Read application's main phtml page
    $aszBuf = file( $szFile );

    // Turn array into a single buffer
    $szBuf = implode("", $aszBuf);

    // Replace title using a regex
    $szBuf = preg_replace("'<TITLE>Untitled</TITLE>'si",
                        "<TITLE>".$URL["szTitle"]."</TITLE>", $szBuf);

    // open the file
    $fp = fopen( $szFile, "w" );

    // write
    fwrite( $fp, $szBuf );

    // close
    fclose( $fp );
}
?>
