<?php
/**
 * @project     PHP Utils
 * @revision    $Id: app_drawmap.php,v 1.9.2.1 2004/07/15 21:08:08 zak Exp $
 * @purpose     This file outputs the current map file to sceen
 * @author      William A. Bronsema, C.E.T. (bronsema@dmsolutions.ca)
 * @copyright
 * <b>Copyright (c) 2002, DM Solutions Group Inc.</b>
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 **/

/*****************************************************************************
 * $Log: app_drawmap.php,v $
 * Revision 1.9.2.1  2004/07/15 21:08:08  zak
 * updated mapscript module reference to 43
 * removed obsolete image type checking code
 *
 * Revision 1.9  2002/09/05 15:01:03  bronsema
 * moved all includes to the top of the page to fix path issues in Linux
 *
 * Revision 1.8  2002/08/08 03:07:11  bronsema
 * Updated to generic drawmap.php
 *
 * Revision 1.2  2002/08/08 02:24:02  bronsema
 * Completed construction
 *
 * Revision 1.1  2002/08/07 23:44:18  bronsema
 * Initial addition
 *
 *
 *****************************************************************************/
/*****************************************************************************
 * The following parameters are REQUIRED when caling this page:
 * 
 *      map_session_mode : integer
 *                          0 indicates the map session is read-only,
 *                          1 indicates the map session is read-write.
 * 
 *      run_query : integer
 *                          0 indicates a query is NOT to be run,
 *                          1 indicates a query is to be run.
 *       
 * The following parameters are OPTIONAL when caling this page:
 * (They can be set using session variables of the same name)
 * 
 *      gszMapName : string 
 *                          Path and filename to the mapfile.  This value can
 *                          be included in the URL if sessions are NOT used
 *                          OR can be set using a DEFINE statment as outlined
 *                          in the code below.
 * 
 *      gszCurrentState : string 
 *                          The map session current state key.  Defaults to "" 
 *                          if not supplied.
 *
 *      $szMapPath : string 
 *                          The path to where mapscript "thinks" the mapfile is
 *                          located.  Defaults to the path of the given mapfile
 *                          if not given.
 *  
 *      gszPHPMapScriptModName : string
 *                          The mapscript module name.  Default to 
 *                          "php_mapscript.so (or .dll)" if not given.
 * 
 *      gszTmpMapPath : string
 *                          The path for the temporary map files in read-write 
 *                          mode.  Defaults to the path of the given mapfile if
 *                          not given.
 * 
 *      gszQueryLayers : string
 *                          Comma delimited string of layer indexes to query.  
 *                          If not supplied and a query is called for then all
 *                          visible layers will be queried.
 * 
 *      gszQueryCoords : string
 *                          String of co-ordinates in the following format:
 *                          minx,miny;maxx,maxy
 *                          This value MUST be supplied if a query is performed.
 *   
 *****************************************************************************/

/* ============================================================================
 * Un-comment the following code if the mapfile is to be DEFINED instead of in
 * session or URL.
 * ========================================================================= */
//DEFINE( "MAPFILE", "./mymap.map" );

/* ============================================================================
 * Include necessary files
 * ========================================================================= */
include_once( "../logger/logfile.php" );
include_once( "../logger/error_manager.php" );
include_once( "../logger/logger.php" );
include_once( "./map_session.php" );
include_once( "./map_query.php" );
 
/* ============================================================================
 * setup values
 * ========================================================================= */
// build an array with the HTTP GET or POST parameters
$http_form_vars = (count($_POST) > 0) ? 
                  $_POST : ((count($_GET) > 0) ? $_GET : array() );
                  
// determine current page location
$szURI = "http://".$_SERVER['HTTP_HOST'].dirname($_SERVER['PHP_SELF']);   
                  
/* ============================================================================
 * Determine the required values
 * ========================================================================= */                  
// default values
$szMapName = ( defined( "MAPFILE" ) ? MAPFILE : "?");
$szMapPath = "?";
$szMSModName = "?";
$szTmpMapPath = "?";
$szCurrentState = "?";
$szQueryLayers = "?";
$szQueryCoords = "?";

// determine if in session
$sess_name = "sid";

// only setup session if set
if ( isset( $http_form_vars[$sess_name] ) )
{               
    // turn off cookies for propagating session ids
    ini_set( "session.use_cookies", "0" );
    
    // turn off tranparent SID (becuase of buffer problem) 
    ini_set( "session.use_trans_sid", "0" );
    
    // name the session
    session_name( $sess_name );
    
    // use passed session id or start a new one
    session_id( $http_form_vars[$sess_name]);
    
    // start the session
    session_start();
    
    // check for map name
    if ( $szMapName == "?" && isset( $_SESSION["gszMapName"] ) ) 
        $szMapName = $_SESSION["gszMapName"];

    // check for map path
    if ( $szMapPath == "?" && isset( $_SESSION["gszMapPath"] ) ) 
        $szMapPath = $_SESSION["gszMapPath"];        
        
    // check for mapscript module name
    if ( $szMSModName == "?" && isset( $_SESSION["gszPHPMapScriptModName"] ) ) 
        $szMSModName = $_SESSION["gszPHPMapScriptModName"];    
    
    // check for the temp mapfile path
    if ( $szTmpMapPath == "?" && isset( $_SESSION["gszTmpMapPath"] ) ) 
        $szTmpMapPath = $_SESSION["gszTmpMapPath"];
    
    // check for the map session key
    if ( $szCurrentState == "?" && isset( $_SESSION["gszCurrentState"] ) ) 
        $szCurrentState = $_SESSION["gszCurrentState"];    

    // check for the query layers
    if ( $szQueryLayers == "?" && isset( $_SESSION["gszQueryLayers"] ) ) 
        $szQueryLayers = $_SESSION["gszQueryLayers"];    

    // check for the query co-ordinates
    if ( $szQueryCoords == "?" && isset( $_SESSION["gszQueryCoords"] ) ) 
        $szQueryCoords = $_SESSION["gszQueryCoords"]; 
    
    // close session
    session_write_close();
}

// check URL if values not yet set
if ( $szMapName == "?" && isset($http_form_vars["gszMapName"]) )
    $szMapName = $http_form_vars["gszMapName"];
if ( $szMapPath == "?" && isset($http_form_vars["gszMapPath"]) )
    $szMapPath = $http_form_vars["gszMapPath"];     
if ( $szMSModName == "?" && isset($http_form_vars["gszPHPMapScriptModName"]) )
    $szMSModName = $http_form_vars["gszPHPMapScriptModName"];
if ( $szTmpMapPath == "?" && isset($http_form_vars["gszTmpMapPath"]) )
    $szTmpMapPath = $http_form_vars["gszTmpMapPath"];
if ( $szCurrentState == "?" && isset($http_form_vars["gszCurrentState"]) )
    $szCurrentState = $http_form_vars["gszCurrentState"];
if ( $szQueryLayers == "?" && isset($http_form_vars["gszQueryLayers"]) )
    $szQueryLayers = $http_form_vars["gszQueryLayers"];
if ( $szQueryCoords == "?" && isset($http_form_vars["gszQueryCoords"]) )
    $szQueryCoords = $http_form_vars["gszQueryCoords"];        

// default the map path if not set
if ( $szMapPath == "?" ) $szMapPath = dirname( $szMapName );
        
// default mapscript module name as a last resort
if ( $szMSModName == "?" )
{
    // set according to OS
    $szMSModName = ( (PHP_OS == "WINNT" || PHP_OS == "WIN32") ? 
                                    "php_mapscript.dll" : "php_mapscript.so" );
}

// default the temp map path as a last resort
if ( $szTmpMapPath == "?" ) $szTmpMapPath = dirname( $szMapName );

// default the statekey as a last resort
if ( $szCurrentState == "?" ) $szCurrentState = "";

// default the query co-ordinates if necessary
if ( $szQueryCoords == "?" ) $szQueryCoords = "0,0";

// check for trailing "/" in path names
$szTmpMapPath = str_replace("\\", "/", $szTmpMapPath);
if (substr($szTmpMapPath, -1) != "/") $szTmpMapPath .= "/";
$szMapPath = str_replace("\\", "/", $szMapPath);
if (substr($szMapPath, -1) != "/") $szMapPath .= "/";
$szMapName = str_replace("\\", "/", $szMapName);

/** DEBUG
echo "MapName: $szMapName<br>";
echo "MapPath: $szMapPath<br>";
echo "ModuleName: $szMSModName<br>";
echo "TmpPath: $szTmpMapPath<br>";
echo "CurrentState: $szCurrentState<br>";
echo "QueryLayers: $szQueryLayers<br>";
echo "QueryCoords: $szQueryCoords<br>";

/*
$aszLog = explode(".", basename($_SERVER["PHP_SELF"]));
$gLogFile = new LogFile( $szTmpMapPath.$aszLog[0]."_drawmap.log", LOG_TO_FILE, true );
$gLogFile->setMaxLogLevel( LOG_ALL );
$gErrorManager = new ErrorManager();
$oLog = new Logger( "General" );
$oLog->setLogFile( $gLogFile );
$oLog->setErrorManager( $gErrorManager );
*/
// ensure that the mapscript module is loaded
if (!extension_loaded("MapScript")) dl($szMSModName);

/* ============================================================================
 * Setup the map session & navigator classes
 * ========================================================================= */
if ( $http_form_vars["map_session_mode"] == 0 )
{
    // create a new map session object in read-only mode
    $oMapSession = new MapSession_R;
}
else
{
    // create a new map session object in read-write mode
    $oMapSession = new MapSession_RW;
    
    // set the temp directory for the map session
    $oMapSession->setTempDir( $szTmpMapPath );
}
/*
$oMapSession->setLogFile( $gLogFile );
$oMapSession->setErrorManager( $gErrorManager );
/* ============================================================================
 * Re-instate the previous map state
 * ========================================================================= */
$oMapSession->restoreState( $szCurrentState, $szMapName, $szMapPath );

/* ============================================================================
 * Draw map
 * ========================================================================= */
// run query if necessary
if ( $http_form_vars["run_query"] == 1 )
{
    // run query
    runQuery( $oMapSession, $szQueryCoords, $szQueryLayers, $szURI );
    
    // draw map with query
    $oImage = $oMapSession->oMap->drawQuery();
}
else
{
    // draw map
    $oImage = $oMapSession->oMap->draw();
}

/* ============================================================================
 * Determine image support -- obsolete in ms 4.x - uses map value
 * ========================================================================= */
// check gif first
//if (strpos( ms_GetVersion(), "OUTPUT=GIF") > 0 )
//{
//    // gif is supportted
//    $szImageType = 'GIF';
//}
//elseif(strpos( ms_GetVersion(), "OUTPUT=PNG") > 0 )
//{
//    // png is supportted
//    $szImageType = 'PNG';
//}
//else
//{
//    // default to JPEG
//    $szImageType = 'JPEG';
//}

// set the output type
//switch ($szImageType)
//{
//   case 'GIF':
//       header("Content-type: image/gif");
//       break;
//   case 'PNG':
//       header("Content-type: image/png");
//       break;
//   case 'JPEG':
//       header("Content-type: image/jpeg");
//       break;
//}

// output map
$url = $oImage->saveImage("");

/**
 * This function takes the given query parameters and executes a query on the
 * given map session's map object.
 * 
 * @param $oMapSession object - Map Session object.
 * @param $szQueryCoords string - Delimited string of co-ordinates.
 * @param $szQueryLayers string - Comma delimited string of layer indexes.
 * @return boolean - True if successful, False if not.
 **/
function runQuery( $oMapSession, $szQueryCoords, $szQueryLayers )
{
    // create a new map query object
    $oMapQuery = new MapQuery( $oMapSession );

    // process coordinates
    $aszMinMax = explode( ";", $szQueryCoords );
    $adMin = explode( ",", $aszMinMax[0] );
    $adMax = explode( ",", $aszMinMax[1] );
    
    // initialize var(s)
    $aszLayers = array();
    $oMap = $oMapSession->oMap;
    
    // check to see if the list of layers has been supplied
    if ( $szQueryLayers != "?" )
    {
        // get array of layers
        $aszLayers = explode( $szQueryLayers );
        
        // loop and get the name of each layer
        for ( $i=0; $i<$nCount; $i++ )
        {
            // get layer
            $oLayer = $oMap->getLayer( $aszLayers[$i] );
            
            // update array to be name
            $aszLayers[$i] = $oLayer->name;
        }
    }
    else
    {
        // loop through all layers and add to list of layers to query
        // NOTE:  Layers will only have results generated for them if they
        // have a "template" value set.  The template value does not have
        // to be valid, it could be as simple as "ttt".
        $nCount = $oMap->numlayers;   
        for ( $i=0; $i<$nCount; $i++ )
        {
            // get layer name
            $oLayer = $oMap->getLayer( $i );
    
            // only add if on
            if ( $oLayer->status == MS_ON || $oLayer->status == MS_DEFAULT )
            {
                array_push( $aszLayers, $oLayer->name );
            }
        }
    }
    
    // commit
    $oMapQuery->setQueryLayersByName( $aszLayers );

    // execute query
    if ( is_numeric( $adMax[0] ) && is_numeric( $adMax[1] ) )
        $oResultSet = $oMapQuery->executeRectQuery( $adMin[0],
                                    $adMin[1],$adMax[0], $adMax[1] );
    else
        $oResultSet = $oMapQuery->executePointQuery( $adMin[0],
                                                        $adMin[1] );
                                                        
    // return success
    return true;                                                        
}
?>
